package com.yiqi.core.mapper;


import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.core.domain.GoodsSkuSpec;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 商品规格Mapper接口
 *
 * @author ruoyi
 * @date 2023-08-30
 */
public interface GoodsSkuSpecMapper extends BaseMapper<GoodsSkuSpec> {
    /**
     * 查询商品规格
     *
     * @param id 商品规格主键
     * @return 商品规格
     */
    public GoodsSkuSpec selectGoodsSkuSpecById(Long id);

    /**
     * 查询商品规格列表
     *
     * @param goodsSkuSpec 商品规格
     * @return 商品规格集合
     */
    public List<GoodsSkuSpec> selectGoodsSkuSpecList(GoodsSkuSpec goodsSkuSpec);

    /**
     * 新增商品规格
     *
     * @param goodsSkuSpec 商品规格
     * @return 结果
     */
    public int insertGoodsSkuSpec(GoodsSkuSpec goodsSkuSpec);

    /**
     * 修改商品规格
     *
     * @param goodsSkuSpec 商品规格
     * @return 结果
     */
    public int updateGoodsSkuSpec(GoodsSkuSpec goodsSkuSpec);

    /**
     * 删除商品规格
     *
     * @param id 商品规格主键
     * @return 结果
     */
    public int deleteGoodsSkuSpecById(Long id);

    /**
     * 批量删除商品规格
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGoodsSkuSpecByIds(Long[] ids);


    /**
     * 查询商品规格列表 通过物料id
     *
     * @param skuId 商品物料id
     * @return 商品规格集合
     */
    public List<GoodsSkuSpec> getSkuSpecListBySkuId(Long skuId);
}
